summaryrefslogtreecommitdiffstats
path: root/webapp/stores
diff options
context:
space:
mode:
Diffstat (limited to 'webapp/stores')
-rw-r--r--webapp/stores/error_store.jsx16
1 files changed, 8 insertions, 8 deletions
diff --git a/webapp/stores/error_store.jsx b/webapp/stores/error_store.jsx
index 4a357472d..e37de40ac 100644
--- a/webapp/stores/error_store.jsx
+++ b/webapp/stores/error_store.jsx
@@ -20,12 +20,12 @@ class ErrorStoreClass extends EventEmitter {
this.removeChangeListener = this.removeChangeListener.bind(this);
this.getLastError = this.getLastError.bind(this);
this.storeLastError = this.storeLastError.bind(this);
- this.getIgnoreEmailPreview = this.getIgnoreEmailPreview.bind(this);
- this.ignore_email_preview = false;
+ this.getIgnoreNotification = this.getIgnoreNotification.bind(this);
+ this.ignore_notification = false;
}
- getIgnoreEmailPreview() {
- return this.ignore_email_preview;
+ getIgnoreNotification() {
+ return this.ignore_notification;
}
emitChange() {
@@ -65,8 +65,8 @@ class ErrorStoreClass extends EventEmitter {
clearLastError() {
var lastError = this.getLastError();
- // preview message can only be cleared by clearPreviewError
- if (lastError && lastError.email_preview) {
+ // preview message can only be cleared by clearNotificationError
+ if (lastError && lastError.notification) {
return;
}
@@ -77,8 +77,8 @@ class ErrorStoreClass extends EventEmitter {
}
}
- clearPreviewError() {
- this.ignore_email_preview = true;
+ clearNotificationError() {
+ this.ignore_notification = true;
this.storeLastError('');
this.clearLastError();
}